'''Partial class to handle Vultr ReservedIP API calls'''
from .utils import VultrBase, update_params


class VultrReservedIP(VultrBase):
    '''Handles Vultr ReservedIP API calls'''
    def __init__(self, api_key):
        VultrBase.__init__(self, api_key)

    def create(self, dcid, ip_type, params=None):
        ''' /v1/reservedip/create
        POST - account
        Create a new reserved IP. Reserved IPs can only be used within the
        same datacenter for which they were created.

        Link: https://www.vultr.com/api/#reservedip_create
        '''
        params = update_params(params, {
            'DCID': dcid,
            'ip_type': ip_type
        })
        return self.request('/v1/reservedip/create', params, 'POST')



'''Module setup'''
from setuptools import setup

'''
packaging modeled after
https://hynek.me/articles/sharing-your-labor-of-love-pypi-quick-and-dirty/
'''


def read(filename):
    '''Read content from file'''
    return open(filename).read()

setup(
    name='vultr',
    version='1.0.0',
    install_requires=[
        "requests"
    ],
    description='Vultr.com API Client',
    long_description=(read('README.rst')),
    url='http://github.com/spry-group/python-vultr',
    author='Darrel O\'Pry',
    author_email='darrel.opry@spry-group.com',
    packages=['vultr'],
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    license=read('LICENSE'),
    test_suite='tests'
)



'''Partial class to handle Vultr Backup API calls'''
from .utils import VultrBase


class VultrBackup(VultrBase):
    '''Handles Vultr Backup API calls'''
    def __init__(self, api_key):
        VultrBase.__init__(self, api_key)

    def list(self, params=None):
        ''' /v1/backup/list
        GET - account
        List all backups on the current account

        Link: https://www.vultr.com/api/#backup_backup_list
        '''
        params = params if params else dict()
        return self.request('/v1/backup/list', params, 'GET')
